#
# spec file for package kubernetes1.29
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?tmpfiles_create:%global tmpfiles_create systemd-tmpfiles --create}
# baseversion - version of kubernetes for this package
%define baseversion 1.29
%define baseversionminus1 1.28

Name:           kubernetes%{baseversion}
Version:        1.29.8
Release:        1.1
Summary:        Container Scheduling and Management
License:        Apache-2.0
Group:          System/Management
URL:            https://kubernetes.io/
Source:         kubernetes-%{version}.tar.xz
Source2:        genmanpages.sh
Source3:        kubelet.sh
#systemd services
Source10:       kubelet.service
#config files
Source22:       sysconfig.kubelet-kubernetes
Source23:       kubeadm.conf
Source24:       90-kubeadm.conf
Source25:       10-kubeadm.conf
Source27:       kubelet.tmp.conf
Source28:       kubernetes-rpmlintrc
Source29:       kubernetes.obsinfo
# Patch to change the default registry to registry.opensuse.org/kubic
Patch2:         kubeadm-opensuse-registry.patch
# Patch to change the version check server to kubic.opensuse.org
Patch3:         opensuse-version-checks.patch
# Patch to change the default flexvolume path in kubeadm to match that used by our kubelet, else kubeadm tries to write to /usr when kubelet is already looking at a path on /var thanks to the fix to bsc#1084766
Patch4:         kubeadm-opensuse-flexvolume.patch
# Patch to revert renaming of coredns image location to match how it's done on download.opensuse.org
Patch5:         revert-coredns-image-renaming.patch
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  go >= 1.22.5
BuildRequires:  go-go-md2man
BuildRequires:  golang-packaging
BuildRequires:  rsync
BuildRequires:  systemd-rpm-macros
BuildRequires:  golang(API) = 1.22
BuildRequires:  golang(github.com/jteeuwen/go-bindata)
ExcludeArch:    %{ix86} s390 ppc64

%description
Kubernetes is a system for automating deployment, scaling, and
management of containerized applications.

It groups containers that make up an application into logical units
for management and discovery.
















# packages to build containerized control plane

%package apiserver
Summary:        Kubernetes apiserver for container image
Group:          System/Management
Provides:       kubernetes-apiserver-provider = %{version}
Conflicts:      kubernetes-apiserver-provider

%description apiserver
This subpackage contains the kube-apiserver binary for Kubic images

%package controller-manager
Summary:        Kubernetes controller-manager for container image
Group:          System/Management
Provides:       kubernetes-controller-manager-provider = %{version}
Conflicts:      kubernetes-controller-manager-provider

%description controller-manager
This subpackage contains the kube-controller-manager binary for Kubic images

%package scheduler
Summary:        Kubernetes scheduler for container image
Group:          System/Management
Provides:       kubernetes-scheduler-provider = %{version}
Conflicts:      kubernetes-scheduler-provider

%description scheduler
This subpackage contains the kube-scheduler binary for Kubic images

%package proxy
Summary:        Kubernetes proxy for container image
Group:          System/Management
Provides:       kubernetes-proxy-provider = %{version}
Conflicts:      kubernetes-proxy-provider
Requires:       conntrack-tools
Requires:       ebtables
Requires:       ipset
Requires:       iptables

%description proxy
This subpackage contains the kube-proxy binary for Kubic images

%package kubelet
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet-common
Recommends:     kubernetes-kubelet-common = %{version}
Provides:       kubernetes-kubelet%{baseversion} = %{version}
Obsoletes:      kubernetes-kubelet%{baseversion} < %{version}
%{?systemd_requires}

%description kubelet
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon (current version)

%package kubelet-common
Summary:        Kubernetes kubelet daemon
Group:          System/Management
Requires:       cri-runtime
Requires:       kubernetes-kubelet%{baseversion}
Provides:       kubernetes-kubelet-common = %{version}
Conflicts:      kubernetes-kubelet-common

%description kubelet-common
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubelet daemon

%package kubeadm
Summary:        Kubernetes kubeadm bootstrapping tool
Group:          System/Management
Provides:       kubernetes-kubeadm-provider = %{version}
Conflicts:      kubernetes-kubeadm-provider
Obsoletes:      kubernetes%{baseversionminus1}-kubeadm
Requires:       cri-runtime
Requires:       cri-tools
Requires:       ebtables
Requires:       ethtool
Requires:       kubernetes-kubeadm-criconfig
Requires:       socat
Requires(pre):  shadow
Requires:       (kubernetes%{baseversion}-kubelet or kubernetes%{baseversionminus1}-kubelet)
Recommends:     kubernetes%{baseversion}-kubelet

%description kubeadm
Manage a cluster of Linux containers as a single system to accelerate Dev and simplify Ops.
kubeadm bootstrapping tool

%package client
Summary:        Kubernetes client tools
Group:          System/Management
Provides:       kubernetes-client-provider = %{version}
Requires:       kubernetes%{baseversion}-client-common
Requires(post): update-alternatives
Requires(postun): update-alternatives

%description client
Kubernetes client tools like kubectl.

%package client-common
Summary:        Kubernetes client tools common files
Group:          System/Management
Requires:       kubernetes%{baseversion}-client
Provides:       kubernetes-client-common = %{version}
Conflicts:      kubernetes-client-common
Recommends:     bash-completion

%description client-common
Kubernetes client tools common files

%package client-bash-completion
Summary:        Bash Completion for %{name}-client
Group:          System/Shells
BuildRequires:  bash-completion
Requires:       bash-completion
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and bash-completion)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-bash-completion
Provides:       kubernetes-client-bash-completion = %{version}
Conflicts:      kubernetes-client-bash-completion

%description client-bash-completion
Bash command line completion support for %{name}-client

%package client-fish-completion
Summary:        Fish Completion for %{name}-client
Group:          System/Shells
BuildRequires:  fish
Requires:       kubernetes%{baseversion}-client = %{version}
Supplements:    (kubernetes%{baseversion}-client and fish)
BuildArch:      noarch
Obsoletes:      kubernetes%{baseversionminus1}-client-fish-completion
Provides:       kubernetes-client-fish-completion = %{version}
Conflicts:      kubernetes-client-fish-completion

%description client-fish-completion
Fish command line completion support for %{name}-client.

%prep
%setup -q -n kubernetes-%{version}
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p0
%patch -P 5 -p1

%build
# This is fixing bug bsc#1065972
export KUBE_GIT_COMMIT=$(grep "commit:" %{SOURCE29} | cut -d ":" -f2 | tr -d " ")
# KUBE_GIT_TREE_STATE="clean" indicates no changes since the git commit id
# KUBE_GIT_TREE_STATE="dirty" indicates source code changes after the git commit id
export KUBE_GIT_TREE_STATE="clean"
export KUBE_GIT_VERSION=v%{version}

# https://bugzilla.redhat.com/show_bug.cgi?id=1392922#c1
#%ifarch ppc64le
#export GOLDFLAGS='-linkmode=external'
#%endif

#TEST
export FORCE_HOST_GO=y

%ifarch s390x
# `-buildmode=pie` with "internal linking" is not yet supported on linux/s390x platform
# https://github.com/golang/go/blob/a63907808d14679c723e566cb83acc76fc8cafc2/src/internal/platform/supported.go#L223-L232
# https://github.com/golang/go/issues/64875#issuecomment-1870734528
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm"
%else
make WHAT="cmd/kube-apiserver cmd/kube-controller-manager cmd/kube-scheduler cmd/kube-proxy cmd/kubelet cmd/kubectl cmd/kubeadm" GOFLAGS="-buildmode=pie"
%endif

# The majority of the documentation has already been moved into
# http://kubernetes.io/docs/admin, and most of the files stored in the `docs`
# directory simply point there. That being said, some of the files are actual
# man pages, but they have to be generated with `hack/generate-docs.sh`. So,
# let's do that and run `genmanpages.sh`.
./hack/generate-docs.sh || true
pushd docs
pushd admin
cp kube-apiserver.md kube-controller-manager.md kube-proxy.md kube-scheduler.md kubelet.md ..
popd
cp %{SOURCE2} genmanpages.sh
bash genmanpages.sh
popd

%install

%ifarch ppc64le aarch64
output_path="_output/local/go/bin"
%else
output_path="_output/local/bin/linux/%{go_arch}"
%endif

install -m 755 -d %{buildroot}%{_bindir}

echo "+++ INSTALLING kubeadm"
install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/kubeadm

binaries=(kube-apiserver kube-controller-manager kube-scheduler kube-proxy)
for bin in "${binaries[@]}"; do
  echo "+++ INSTALLING ${bin}"
  install -p -m 755 -t %{buildroot}%{_bindir} ${output_path}/${bin}
done

for bin in kubelet kubectl; do
  echo "+++ INSTALLING ${bin} with %{baseversion} suffix"
  install -p -m 755 ${output_path}/${bin} %{buildroot}%{_bindir}/${bin}%{baseversion}
done

echo "+++ INSTALLING kubelet multi-version loader"
install -p -m 755 %{SOURCE3} %{buildroot}%{_bindir}/kubelet

# create sysconfig.kubelet-kubernetes in fullupdir
sed -i -e 's|BASE_VERSION|%{baseversion}|g' %{SOURCE22}
install -D -m 0644 %{SOURCE22} %{buildroot}%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# install the bash completion
install -d -m 0755 %{buildroot}%{_datadir}/bash-completion/completions/
%{buildroot}%{_bindir}/kubectl%{baseversion} completion bash > %{buildroot}%{_datadir}/bash-completion/completions/kubectl

# install the fish completion
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}%{_bindir}/kubectl%{baseversion} completion fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/kubectl.fish

# move CHANGELOG-%{baseversion}.md to old location
mv CHANGELOG/CHANGELOG-%{baseversion}.md .

# cleanup before copying dirs...
rm -f hack/.linted_packages
find .    -name '.gitignore' -type f -delete
find hack -name '*.sh.orig' -type f -delete
find hack -name '.golint_*' -type f -delete

# systemd service
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 -t %{buildroot}%{_unitdir}/ %{SOURCE10}

# make symlinks to rc files
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf service "%{buildroot}%{_sbindir}/rckubelet"

# install manpages
install -d %{buildroot}%{_mandir}/man1
install -p -m 644 docs/man/man1/* %{buildroot}%{_mandir}/man1

# create config folder
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}

# manifests file for the kubelet
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/manifests

# place kubernetes.tmp.conf to /usr/lib/tmpfiles.d/kubernetes.conf
install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -D -m 0644 %{SOURCE27} %{buildroot}/%{_tmpfilesdir}/kubelet.conf

# install the place the kubelet defaults to put volumes
install -d %{buildroot}%{_localstatedir}/lib/kubelet

%define volume_plugin_dir %{_localstatedir}/lib/kubelet/volume-plugin
install -d %{buildroot}/%{volume_plugin_dir}

# Add kubeadm modprobe.d and sysctl.d drop-in configs
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
mkdir -p %{buildroot}%{_sysctldir}
install -m 0644 -t %{buildroot}%{_prefix}/lib/modules-load.d/ %{SOURCE23}
install -m 0644 -t %{buildroot}%{_sysctldir} %{SOURCE24}

# Create kubeadm systemd unit drop-in
install -d -m 0755 %{buildroot}%{_unitdir}/kubelet.service.d
sed -i -e 's|PATH_TO_FLEXVOLUME|%{volume_plugin_dir}|g' %{SOURCE25}
install -m 0644 -t %{buildroot}%{_unitdir}/kubelet.service.d/ %{SOURCE25}

# alternatives
ln -s -f %{_sysconfdir}/alternatives/kubectl %{buildroot}%{_bindir}/kubectl

%fdupes -s %{buildroot}

%post client-common
%{_sbindir}/update-alternatives \
  --install %{_bindir}/kubectl kubectl %{_bindir}/kubectl%{baseversion} %(echo %{baseversion} | tr -d .)

%postun client-common
if [ ! -f %{_bindir}/kubectl%{baseversion} ] ; then
  update-alternatives --remove kubectl %{_bindir}/kubectl%{baseversion}
fi

%pre kubelet-common
%service_add_pre kubelet.service

%post kubelet-common
%fillup_only -an kubelet
# Check if /etc/sysconfig/kubelet exists
if [ -e "/etc/sysconfig/kubelet" ]; then
  # Extract the value from the fillup file
  UPDATED_KUBELET_VER=$(grep '^KUBELET_VER=' %{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion} | cut -d '=' -f2)
  # Update the value in the sysconfig file
  sed -i "s/^KUBELET_VER=.*/KUBELET_VER=$UPDATED_KUBELET_VER/" /etc/sysconfig/kubelet
fi
%service_add_post kubelet.service
if [ $1 -eq 1 ]; then
    # Check if modprobe command is available
    [ ! -x /sbin/modprobe ] || { /sbin/modprobe br_netfilter && /sbin/modprobe overlay; } || true
fi
%if 0%{?suse_version} < 1500
# create some subvolumes needed by CNI
if [ ! -e %{_localstatedir}/lib/cni ]; then
  if [ "`findmnt -o FSTYPE -l  /|grep -v FSTYPE`" = "btrfs" ]; then
    %{_sbindir}/mksubvolume %{_localstatedir}/lib/cni
  fi
fi
%endif
%tmpfiles_create %{_tmpfilesdir}/kubelet.conf

%preun kubelet-common
%service_del_preun kubelet.service

%postun kubelet-common
%service_del_postun kubelet.service

%post kubeadm
# Check if sysctl command is available
if [ -x /usr/sbin/sysctl ]; then
    # Run sysctl --system after the package installation
    /usr/sbin/sysctl -p %{_sysctldir}/90-kubeadm.conf || true
fi

%files kubelet-common
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%license LICENSE
%{_mandir}/man1/kubelet.1%{?ext_man}
%{_bindir}/kubelet
%{_unitdir}/kubelet.service
%dir %{_unitdir}/kubelet.service.d
%{_sbindir}/rckubelet
%dir %{_localstatedir}/lib/kubelet
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/manifests
%{_tmpfilesdir}/kubelet.conf
%attr(0750,root,root) %dir %ghost %{_rundir}/%{name}
%dir %{volume_plugin_dir}
%{_fillupdir}/sysconfig.kubelet-kubernetes%{baseversion}

# openSUSE is using kubeadm with containerizied control plane, we
# only need the binaries

%files apiserver
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-apiserver.1%{?ext_man}
%{_bindir}/kube-apiserver

%files controller-manager
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-controller-manager.1%{?ext_man}
%{_bindir}/kube-controller-manager

%files scheduler
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-scheduler.1%{?ext_man}
%{_bindir}/kube-scheduler

%files proxy
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kube-proxy.1%{?ext_man}
%{_bindir}/kube-proxy

%files kubelet
%license LICENSE
%{_bindir}/kubelet%{baseversion}

%files kubeadm
%doc README.md CONTRIBUTING.md CHANGELOG-%{baseversion}.md
%{_unitdir}/kubelet.service.d/10-kubeadm.conf
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/kubeadm.conf
%{_sysctldir}/90-kubeadm.conf
%license LICENSE
%{_bindir}/kubeadm
%{_mandir}/man1/kubeadm*

%files client
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_bindir}/kubectl
%{_bindir}/kubectl%{baseversion}
%ghost %_sysconfdir/alternatives/kubectl

%files client-common
%doc README.md CONTRIBUTING.md
%license LICENSE
%{_mandir}/man1/kubectl.1%{?ext_man}
%{_mandir}/man1/kubectl-*

%files client-bash-completion
%{_datadir}/bash-completion/completions/kubectl

%files client-fish-completion
%{_datadir}/fish/vendor_completions.d/kubectl.fish

%changelog
* Fri Aug 16 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.29.8:
  * Respect controllers on PVCs for retention policy
  * Updating kubelet on Windows to query uuid from registry
  * Update err message before ratcheting feature enabled.
  * Terminate restartable init containers ignoring not-started containers
  * Hot fix for panic on schema conversion.
  * mount-utils: treat syscall.ENODEV as corrupted mount
  * update container ubuntu sha256
  * update driver installer
  * api: fix ValidatingAdmissionPolicyList json tag
  * apiserver: fix watch namespace
  * Fix that PodIP field is not set for terminal pod
  * Use omitempty for optional fields in Job Pod Failure Policy
* Tue Aug  6 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Follow up changes after go version bump to 1.22:
  - For ppc64le platform: disabled `export GOLDFLAGS='-linkmode=external'`.   * to fix the build failure error:
    `-linkmode=external requires external (cgo) linking, but cgo is not enabled`
  - For linux/s390x platform: disabled building kubernetes binaries with `-buildmode=pie`
  * `-buildmode=pie` with "internal linking" is not yet supported on linux/s390x platform
  * ref: https://github.com/golang/go/blob/a63907808d14679c723e566cb83acc76fc8cafc2/src/internal/platform/supported.go#L223-L232
  * ref: https://github.com/golang/go/issues/64875#issuecomment-1870734528
* Tue Aug  6 2024 priyanka.saggu@suse.com
- Update to version 1.29.7:
  * Add funcs in pkg/filesystem/util that can actually set file permissiosn on Windows and update container log dir perms to 660 on Windows
  * Fix pv reclaim failed due to its phase is wrongly updated to the Failed state by kcm
  * fix issue with using feature HonorPVReclaimPolicy in csi-provisioner
  * Mark a test case which sets up a sample-apiserver as serial due to potential conflicts with other test cases which do the same.
  * defaultMaskedPaths must be kept in sync with moby/moby.
  * gitRepo volume: directory must be max 1 level deep
  * Bump images, dependencies and versions to go 1.22.5 and distroless iptables
  * Fix endpoints status out-of-sync when the pod state changes rapidly
  * kubeadm: don't fail post upgrade in EnsureAdminClusterRoleBindingImpl if the error is crb already exists
  * fix: skip isPodWorthRequeuing only when SchedulingGates gates the pod
  * kubectl create cronjobs: Manually set OwnerReferences
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.22.5`
  * `BuildRequires:  golang(API) = 1.22`
  * ref: https://github.com/kubernetes/kubernetes/blob/v1.29.7/build/dependencies.yaml#L119-L121
* Wed Jun 26 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.29.6:
  * Bump images, dependencies and versions to go 1.21.11 and distroless iptables/setcap/debian-base
  * Don't fill in NodeToStatusMap with UnschedulableAndUnresolvable
  * Revert "scheduler: preallocation for NodeToStatusMap"
  * add an integration test when nodeAffinity specifies a non-existent node.
  * base on allNodes when calculating nextStartNodeIndex
  * Don't sort under lock
  * Fix printPod panic with spurious container statuses
  * Fix NFS related issues on GCP/Ubuntu
  * cherry pick #124618 to 1.29
  * fix requests tracker concurrency
  * fix conflict race in statefulset rest update
  * fix stateful set pod recreation and event spam
  * fix pods tracking and internal error checking in statefulset tests
  * Updated & added visibility to apiserver x509 test certificates expiring this year
  * Fix PersistentVolumeLabel admission plugin on Azure
* Fri May 17 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.29.5:
  * scheduler: preallocation for NodeToStatusMap
  * add e2e test when a plugin (in-tree or out-of-tree) return non-existent/illegal nodes, the pod should be scheduled normally if suitable nodes exists
  * add integration test for pod with pvc has node-affinity to non-existent/existent nodes
  * test to catch illegal nodeNames returned by PreFilterResult
  * hotfix when a plugin (in-tree or out-of-tree) return non-existent/illegal nodes, the pod scheduling flow will abort immediately.
  * kubeadm: fix upgrading external CA cluster to 1.29
  * Idempotent transformers in scheduler & kcm
  * cluster/gce: upgrade cos-97-lts -> cos-109-lts
  * storage e2e: update hostpath and mock images
  * add log verbosity to endpoint topology hint loop.
  * Rename `cluster` to `storage_cluster_id` for apiserver_storage_size_bytes metric
* Thu Apr 18 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- Update to version 1.29.4:
  * Add envFrom to serviceaccount admission plugin
  * update debian-base to bookworm-v1.0.2
  * [go] Bump images, dependencies and versions to go 1.21.9 and distroless iptables / set-cap
  * [CVE-2023-45288] .*: bump x/net to v0.23.0
  * Keep streams from being set up after closeAllStreamReaders is called
  * Make websocket heartbeat test timing less flaky
  * Avoid logging binary junk for frame write failure
  * Use the right feature gate when updating uncertain volumes
  * fix panic with SIGSEGV in kubeadm certs check-expiration
  * retry policy creation for CRD type checking E2E test
  * Undo double run of the TestWatchSemantics test to avoid hitting timeout
  * apiserver/storage/cacher: decrease the running time of tests in the cacher package.
  * Serve watch without resourceVersion from cache and introduce a WatchFromStorageWithoutResourceVersion feature gate to allow serving watch from storage.
  * Ensure that initial events are sorted for WatchList
  * fix aggregator path filtering to include /
  * Filter aggregated apiservice gv
  * Use DBG=1 for conformance verification
  * build: use -trimpath in non-DBG mode
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.21.9`
  * ref: https://github.com/kubernetes/kubernetes/blob/v1.29.4/build/dependencies.yaml#L119-L121
* Mon Apr  8 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- update .spec file to set FORCE_HOST_GO env variable,
  to force k8s build scripts use the local GOTOOLCHAIN version from the build pipeline
  (i.e. GOTOOLCHAIN='local')
  * ref: https://github.com/kubernetes/kubernetes/blob/9791f0d1f39f3f1e0796add7833c1059325d5098/hack/lib/golang.sh#L507
* Mon Apr  8 2024 priyanka.saggu@suse.com
- Update to version 1.29.3:
  * remove --v arg from kubetest2-tester-ginkgo test args
  * ci: bump kind to latest for kms jobs
  * [go] Bump images, dependencies and versions to go 1.21.8 / distroless-iptables to v0.4.6
  * [CVE-2024-24786] Bump github.com/golang/protobuf v1.5.4, google.golang.org/protobuf v1.33.0
  * keep existing PDB conditions when updating status
  * Validate restartable init container state transition
  * Test that separation of streams work by using progress notifies
  * Prevent watch cache starvation, by moving its watch to separate RPC and add a SeparateCacheWatchRPC feature flag to disable this behavior
  * fix UT failure TestPrintIPAddressList
  * etcd: Update to version 3.5.12
  * build etcd image v3.5.12
  * Fix race condition between external-resizer and kubelet
  * codegen: don't nuke files if only verifying
  * dra: increase timeout in setupFakeDRADriverGRPCServer to prevent tests to flake.
  * e2e_node: replace `registry.k8s.io/stress:v1` with agnhost
  * promote agnhost to v2.47
  * fixing issue with GetCPUUsageNanoCores on Windows
  * Fix cleanup of file subpaths
  * Fix SELinux e2e tests: add label to observed metrics
- Update .spec file to bump go version build requirements:
  * `BuildRequires:  go >= 1.21.18`
  * ref: https://github.com/kubernetes/kubernetes/blob/v1.29.3/build/dependencies.yaml#L119-L121
* Mon Feb 26 2024 priyanka.saggu@suse.com
- Update to version 1.29.2:
  * [go] Bump images, dependencies and versions to go 1.21.7 / setcap/debian-base to bookworm-v1.0.1 and distroless-iptables to v0.4.5
  * Revert "kubeadm: fix a bug where the uploaded kubelet configuration in kube-system/kubelet-config ConfigMap does not respect user patch"
  * kubeadm: better checks if the node is CP during "upgrade node"
  * test: remove unnecessary skip healthz check from test
  * bugfix: dont skip reconcile for unchanged policy if last sync failed
  * Add processStartTime in metrics/slis
  * Fix deprecated version for pod_scheduling_duration_seconds
  * flag PersistentVolumeLastPhaseTransitionTime field as beta
  * If a pvc has an empty storageclass name, don't try to assign a default StorageClass to it.
  * Fix kubeadm init regression
  * Drop PendingChanges methods from change trackers, move into UpdateResults
  * Squash some unnecessarily-chained methods in the change trackers
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Jan 23 2024 priyanka.saggu@suse.com
- Update to version 1.29.1:
  * Revert "Graduate Evented PLEG to Beta"
  * [go] Bump images, dependencies and versions to go 1.21.6 and distroless iptables to 0.4.4
  * Make OpenAPIGetter tolerant of nil
  * use context for lazy evaluation.
  * Initialize default attach func regardless of the value of flag
  * .*: bump golang.org/x/tools to v0.16.1
  * fix: 119921
  * Keep presence cost to 0 to ensure backward compatibility.
  * fix(scheduler): fix incorrect loop logic in MultiPoint to avoid a plugin being loaded multiple times
  * fix falky test pkg/registry/core/persistentvolume/storage TestUpdateStatus
  * Use a separate function for checking if device was reconstructed
  * Add tests for checking of uncertain device paths
  * Fix device uncertain errors on reboot
  * Fix CSI migration for vSphere volumes
  * Wire in field dropping for CRDs
  * Revert "scheduler/nodeaffinity: reduce pod scheduling latency"
  * Revert "scheduler/NodeUnschedulable: reduce pod scheduling latency"
  * kube-proxy: Fix etp:Local for externalIPs
  * Add unit test for Job Controller for panic when PodFailurePolicy is used on 1.28
* Tue Jan 23 2024 Priyanka Saggu <priyanka.saggu@suse.com>
- initial package for Kubernetes v1.29.0
